summaryrefslogtreecommitdiffstats
path: root/content
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-12 14:43:01 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-12 14:43:01 +0000
commit7da9c4cf0e9f949dd1f2a3322118344c5d7369c7 (patch)
treeec91a8b4f8a211bc557a9bb28b61c17f90749d02 /content
parentc5ba8a93317a8363bcaf4b17cab96a296782803c (diff)
downloadchromium_src-7da9c4cf0e9f949dd1f2a3322118344c5d7369c7.zip
chromium_src-7da9c4cf0e9f949dd1f2a3322118344c5d7369c7.tar.gz
chromium_src-7da9c4cf0e9f949dd1f2a3322118344c5d7369c7.tar.bz2
Rename gfx::Monitor to gfx::Display
BUG=130828 R=oshima@chromium.org TBR=sky@chromium.org Review URL: https://chromiumcodereview.appspot.com/10540091 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@141659 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content')
-rw-r--r--content/browser/renderer_host/dip_util.cc6
-rw-r--r--content/browser/renderer_host/render_widget_host_view_aura.cc10
-rw-r--r--content/browser/web_contents/web_contents_impl.cc2
3 files changed, 9 insertions, 9 deletions
diff --git a/content/browser/renderer_host/dip_util.cc b/content/browser/renderer_host/dip_util.cc
index df0ec63..8a42e74 100644
--- a/content/browser/renderer_host/dip_util.cc
+++ b/content/browser/renderer_host/dip_util.cc
@@ -5,7 +5,7 @@
#include "content/browser/renderer_host/dip_util.h"
#include "content/public/browser/render_widget_host_view.h"
-#include "ui/gfx/monitor.h"
+#include "ui/gfx/display.h"
#include "ui/gfx/point.h"
#include "ui/gfx/rect.h"
#include "ui/gfx/screen.h"
@@ -19,9 +19,9 @@ float GetDIPScaleFactor(const RenderWidgetHostView* view) {
// TODO(pkotwicz): Fix this. (crbug.com/129409).
#if !defined(OS_MACOSX)
if (gfx::Screen::IsDIPEnabled()) {
- gfx::Monitor monitor = gfx::Screen::GetMonitorNearestWindow(
+ gfx::Display display = gfx::Screen::GetMonitorNearestWindow(
view ? view->GetNativeView() : NULL);
- return monitor.device_scale_factor();
+ return display.device_scale_factor();
}
#endif
return 1.0f;
diff --git a/content/browser/web_contents/web_contents_impl.cc b/content/browser/web_contents/web_contents_impl.cc
index 9c73981..3c0cdd7 100644
--- a/content/browser/web_contents/web_contents_impl.cc
+++ b/content/browser/web_contents/web_contents_impl.cc
@@ -70,7 +70,7 @@
#include "third_party/WebKit/Source/WebKit/chromium/public/WebView.h"
#include "ui/base/layout.h"
#include "ui/base/ui_base_switches.h"
-#include "ui/gfx/monitor.h"
+#include "ui/gfx/display.h"
#include "ui/gfx/screen.h"
#include "webkit/glue/web_intent_data.h"
#include "webkit/glue/web_intent_service_data.h"
diff --git a/content/browser/renderer_host/render_widget_host_view_aura.cc b/content/browser/renderer_host/render_widget_host_view_aura.cc
index e96b017..02d13ee 100644
--- a/content/browser/renderer_host/render_widget_host_view_aura.cc
+++ b/content/browser/renderer_host/render_widget_host_view_aura.cc
@@ -41,7 +41,7 @@
#include "ui/compositor/compositor.h"
#include "ui/compositor/layer.h"
#include "ui/gfx/canvas.h"
-#include "ui/gfx/monitor.h"
+#include "ui/gfx/display.h"
#include "ui/gfx/screen.h"
#include "ui/gfx/skia_util.h"
@@ -113,16 +113,16 @@ bool CanRendererHandleEvent(const aura::MouseEvent* event) {
void GetScreenInfoForWindow(WebKit::WebScreenInfo* results,
aura::Window* window) {
- const gfx::Monitor monitor = window ?
+ const gfx::Display display = window ?
gfx::Screen::GetMonitorNearestWindow(window) :
gfx::Screen::GetPrimaryMonitor();
- const gfx::Size size = monitor.size();
+ const gfx::Size size = display.size();
results->rect = WebKit::WebRect(0, 0, size.width(), size.height());
results->availableRect = results->rect;
// TODO(derat|oshima): Don't hardcode this. Get this from monitor object.
results->depth = 24;
results->depthPerComponent = 8;
- int default_dpi = monitor.device_scale_factor() * 160;
+ int default_dpi = display.device_scale_factor() * 160;
results->verticalDPI = default_dpi;
results->horizontalDPI = default_dpi;
}
@@ -113,16 +113,16 @@ bool CanRendererHandleEvent(const aura::MouseEvent* event) {
results->rect = WebKit::WebRect(0, 0, size.width(), size.height());
results->availableRect = results->rect;
- // TODO(derat|oshima): Don't hardcode this. Get this from monitor object.
+ // TODO(derat|oshima): Don't hardcode this. Get this from display object.
results->depth = 24;
results->depthPerComponent = 8;